@@ -18,6 +18,7 @@
 
 #This file controls the datafile scripting, both loading and executing.
 
+from player import *
 
 import g
 import main
@@ -78,6 +79,22 @@ def activate_line(x, y, z, command):
 		if temp != -1:
 			return_num = main.start_battle(temp)
 
+	elif switch == "damage_monster":  #In battle, hurt monster for either
+			#adj_attack points, or Command points. *NOT* reduced by armor.
+		if g.cur_window != "battle":
+			print "damage_monster called outside of battle."
+		temp_command_array = command.split(None, 1)
+
+		mon_num = battle.select_monster()
+		if mon_num == -1: return 0
+		if len(temp_command_array) == 1: #Basic damage_monster command.
+			battle.monster_hurt(mon_num, player.adj_attack)
+			return_num = 1
+		else: #Of the format damage_monster Command.
+			set_to = activate_line(x, y, z, temp_command_array[1])
+			battle.monster_hurt(mon_num, set_to)
+			return_num = 1
+
 	elif switch == "delpix": #remove a picture from the tile.
 		try:
 			g.maps[z].field[y][x].del_pix(
@@ -92,7 +109,7 @@ def activate_line(x, y, z, command):
 		return_num = 1
 
 	elif switch == "die":  #process endgame.txt script
-		g.hp = -1
+		player.hp = -1
 		for line in g.endgame_act:
 			activate_line(x, y, z, line)
 		return_num = "end"
@@ -109,7 +126,7 @@ def activate_line(x, y, z, command):
 		if main.show_yesno("You found " + amount + " " + founditem +
 				"! Would you like to pick it up ?"):
 			if(founditem == "gold"):
-				g.gold = int(g.gold) + int(amount)
+				player.gold = int(player.gold) + int(amount)
 				main.print_message("You picked up " + amount + " " +
 						founditem + ".")
 				has_dialog = 0
@@ -137,35 +154,35 @@ def activate_line(x, y, z, command):
 
 		if switch2 == "name":
 			#note that name is not interpreted as a command. See above.
-			g.name = interpret_line(set_to)
+			player.name = interpret_line(set_to)
 		elif switch2 == "hp":
-			g.hp = g.hp + int(set_to)
-			if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
+			player.hp = player.hp + int(set_to)
+			if player.hp >= player.adj_maxhp: player.hp = player.adj_maxhp
 		elif switch2 == "ep":
-			g.ep = g.ep + int(set_to)
-			if g.ep >= g.adj_maxep: g.ep = g.adj_maxep
-			if g.ep < 0: g.ep = 0
+			player.ep = player.ep + int(set_to)
+			if player.ep >= player.adj_maxep: player.ep = player.adj_maxep
+			if player.ep < 0: player.ep = 0
 		elif switch2 == "maxhp":
-			g.maxhp = g.maxhp + int(set_to)
-			if 1 > g.maxhp: g.maxhp = 1
+			player.maxhp = player.maxhp + int(set_to)
+			if 1 > player.maxhp: player.maxhp = 1
 		elif switch2 == "maxep":
-			g.maxep = g.maxep + int(set_to)
-			if 1 > g.maxep: g.maxep = 1
+			player.maxep = player.maxep + int(set_to)
+			if 1 > player.maxep: player.maxep = 1
 		elif switch2 == "attack":
-			g.attack = g.attack + int(set_to)
-			if 1 > g.attack: g.attack = 1
+			player.attack = player.attack + int(set_to)
+			if 1 > player.attack: player.attack = 1
 		elif switch2 == "defense":
-			g.defense = g.defense + int(set_to)
-			if 1 > g.defense: g.defense = 1
+			player.defense = player.defense + int(set_to)
+			if 1 > player.defense: player.defense = 1
 		elif switch2 == "gold":
-			g.gold = int(g.gold) + int(set_to)
-			if 1 > g.gold: g.gold = 0
+			player.gold = int(player.gold) + int(set_to)
+			if 1 > player.gold: player.gold = 0
 		elif switch2 == "exp":
-			g.add_exp(int(set_to))
-			if 1 > g.exp: g.exp = 0
+			player.add_exp(int(set_to))
+			if 1 > player.exp: player.exp = 0
 		elif switch2 == "skillpoints":
-			g.skillpoints = g.skillpoints + int(set_to)
-			if 1 > g.skillpoints: g.skillpoints = 0
+			player.skillpoints = player.skillpoints + int(set_to)
+			if 1 > player.skillpoints: player.skillpoints = 0
 		else:
 			print "Unknown stat: " + switch2
 		main.recalc_stats()
@@ -173,7 +190,7 @@ def activate_line(x, y, z, command):
 		else: return_num = 1
 
 	elif switch == "hero":  #change hero pix
-		g.cur_hero = "people/" + command.split(None, 2)[1] + ".png"
+		player.cur_hero = "people/" + command.split(None, 2)[1] + ".png"
 		main.refreshmap()
 
 	elif switch == "hurt":  #hurt player (reduced by armor)
@@ -182,10 +199,26 @@ def activate_line(x, y, z, command):
 		set_to = activate_line(x, y, z, command.split(None, 1)[1])
 		if set_to == "end": return "end"
 		damage = g.die_roll(1, int(set_to) + 2)
-		damage = damage - g.die_roll(1, g.adj_defense + 2)
-		g.hp = g.hp - damage
+		damage = damage - g.die_roll(1, player.adj_defense + 2)
+		player.hp = player.hp - damage
 		return_num = 1
 
+	elif switch == "hurt_monster":  #In battle, hurt monster for either
+			#adj_attack points, or Command points. Reduced by armor.
+		if g.cur_window != "battle":
+			print "hurt_monster called outside of battle."
+		temp_command_array = command.split(None, 1)
+
+		mon_num = battle.select_monster()
+		if mon_num == -1: return 0
+		if len(temp_command_array) == 1: #Basic hurt_monster command.
+			battle.attack_monster(mon_num, player.adj_attack)
+			return_num = 1
+		else: #Of the format hurt_monster Command.
+			set_to = activate_line(x, y, z, temp_command_array[1])
+			battle.attack_monster(mon_num, set_to)
+			return_num = 1
+
 	elif switch == "if":
 		temp = command.split(None, 1)[1].strip()
 		compare = 0
@@ -241,7 +274,7 @@ def activate_line(x, y, z, command):
 
 	elif switch == "is_equipped": #is the given item equipped?
 		match = command.split(None, 1)[1].strip().lower()
-		for item_title in g.item.equip:
+		for item_title in player.equip:
 			if item_title == -1: continue
 			if g.item.item[item_title].name.lower() == match:
 				return 1
@@ -253,7 +286,7 @@ def activate_line(x, y, z, command):
 		else: return_num = 1
 
 	elif switch == "lose":
-		g.hp = -1
+		player.hp = -1
 		main.close_window()
 		return_num = "end"
 
@@ -367,27 +400,27 @@ def activate_line(x, y, z, command):
 	elif switch == "stat":  #return stat
 		switch2 = command.split(None, 2)[1].lower()
 		if switch2 == "name":
-			return_num = g.name
+			return_num = player.name
 		elif switch2 == "hp":
-			return_num = g.hp
+			return_num = player.hp
 		elif switch2 == "ep":
-			return_num = g.ep
+			return_num = player.ep
 		elif switch2 == "maxhp":
-			return_num = g.adj_maxhp
+			return_num = player.adj_maxhp
 		elif switch2 == "maxep":
-			return_num = g.adj_maxep
+			return_num = player.adj_maxep
 		elif switch2 == "attack":
-			return_num = g.adj_attack
+			return_num = player.adj_attack
 		elif switch2 == "defense":
-			return_num = g.adj_defense
+			return_num = player.adj_defense
 		elif switch2 == "gold":
-			return_num = g.gold
+			return_num = player.gold
 		elif switch2 == "exp":
-			return_num = g.exp
+			return_num = player.exp
 		elif switch2 == "level":
-			return_num = g.level
+			return_num = player.level
 		elif switch2 == "skillpoints":
-			return_num = g.skillpoints
+			return_num = player.skillpoints
 		else:
 			print "Unknown stat: " + switch2
 			return_num = 0
