@@ -28,6 +28,8 @@ import main
 import action
 import monster
 
+from player import *
+
 mon_index = 0
 
 #mon_hp = StringVar()
@@ -108,15 +110,17 @@ def refresh():
 	for i in g.item.inv:
 		if i != -1 and (g.item.item[i].type == 11 or
 				g.item.item[i].type == 12 or
-				g.item.item[i].type == 14):
+				g.item.item[i].type == 14 or
+				g.item.item[i].type == 15 or
+				g.item.item[i].type == 17):
 			listbox_item.insert(END, g.item.item[i].name)
 
 	#clear and rebuild listbox_skill
 	listbox_skill.delete(0, END)
-	for i in range(len(g.skill)):
-		if g.skill[i][5] == 1 and g.skill[i][2] <= g.ep:
-			listbox_skill.insert(END, g.skill[i][0] + ": "
-				+ str(g.skill[i][2]) + " EP")
+	for i in range(len(player.skill)):
+		if player.skill[i][5] == 1 and player.skill[i][2] <= player.ep:
+			listbox_skill.insert(END, player.skill[i][0] + ": "
+				+ str(player.skill[i][2]) + " EP")
 
 
 #attack button was pressed
@@ -131,13 +135,13 @@ def attack(event=0):
 	clear_slashes()
 
 	#Both hp's *should* be over 0. Just a precaution.
-	if monster_list[last_mon_num].hp > 0 and g.hp > 0:
-		attack_monster(last_mon_num)
+	if monster_list[last_mon_num].hp > 0 and player.hp > 0:
+		attack_monster(last_mon_num, player.adj_attack)
 	global used_gem
 	global num_dice
 	if used_gem == 1:
-	   g.adj_attack = old_attack
-	   main.attack.set(g.adj_attack)
+	   player.adj_attack = old_attack
+	   main.attack.set(player.adj_attack)
 	   num_dice = 1
 	   used_gem = 0
 	attack_player()
@@ -259,22 +263,16 @@ def monster_mouse_move(event=None):
 	except AttributeError:
 		active_button = -1
 
-#attack the i'th monster in monster_list[].
-def attack_monster(i):
+#attack the i'th monster in monster_list[], with an attack of power attack_power.
+def attack_monster(i, attack_power):
 	if i == -1: return
 	global cur_mon_hp
 	#find the damage done
 	global num_dice
-	damage = g.die_roll(num_dice, g.adj_attack + 2)
+	damage = g.die_roll(num_dice, attack_power + 2)
 	damage = damage - g.die_roll(1, monster_list[i].defense + 2)
 	if damage > 0:
- 		main.print_message("You hit the " + monster_list[i].name +
- 			" for " + str(damage) + " damage.")
-		monster_list[i].hp = monster_list[i].hp - damage
-		monster_slashed(i)
-		#you kill it?
-		if monster_list[i].hp <= 0:
-			monster_dead(i)
+		if monster_hurt(i, damage) == 1:
 			return 0
 	else:
 		main.print_message("You miss the " +
@@ -283,22 +281,22 @@ def attack_monster(i):
 #Make all monsters attack the player.
 def attack_player():
 	for i in range(len(monster_list)):
-		if monster_list[i].hp > 0 and g.hp > 0:
+		if monster_list[i].hp > 0 and player.hp > 0:
 			attack_player_per_monster(i)
 
 
 #Make the i'th monster attack you
 def attack_player_per_monster(i):
 	damage = g.die_roll(1, monster_list[i].attack + 2)
-	damage = damage - g.die_roll(1, g.adj_defense + 2)
+	damage = damage - g.die_roll(1, player.adj_defense + 2)
 	if damage > 0:
 		main.print_message("The " + monster_list[i].name +
 		" hits you for " + str(damage) + " damage.")
-		g.hp = g.hp - damage
+		player.hp = player.hp - damage
 		monster_slashed("h")
 		#you dead yet?
-		if g.hp <= 0:
-			g.hp = 0
+		if player.hp <= 0:
+			player.hp = 0
 			main.print_message("The " + monster_list[i].name +
 			" kills you.")
 			cur_button = 1
@@ -332,6 +330,19 @@ def clear_slashes():
 		canvas_mon_pic.delete(canvas_mon_pic.find_withtag("hit"+str(i)))
 	canvas_mon_pic.delete(canvas_mon_pic.find_withtag("hith"))
 
+#Hurts monster i for damage points. Kills it if the damage is great enough.
+def monster_hurt(i, damage):
+	monster_list[i].hp = monster_list[i].hp - damage
+	if damage > 0:
+		monster_slashed(i)
+		main.print_message("The " + monster_list[i].name
+			+ " is hit for " + str(damage) + " damage")
+	#you kill it?
+	if monster_list[i].hp <= 0:
+		monster_dead(i)
+		return 1
+	return 0
+
 #use to reward the player for killing a monster
 def monster_dead(i):
 	global active_button
@@ -343,12 +354,12 @@ def monster_dead(i):
 
 	if len(monster_list[i].on_death) == 0:
 		gold = monster_list[i].gold
-		g.gold = str(int(g.gold) + gold)
+		player.gold = str(int(player.gold) + gold)
 		main.print_message("You find " + str(gold) + " gold,")
 
 		exp = monster_list[i].exp
 		main.print_message("and get " + str(exp) + " experience.")
-		g.add_exp(exp)
+		player.add_exp(exp)
 	else:
 		action.activate_lines(g.xgrid, g.ygrid, g.zgrid,
 					monster_list[i].on_death)
@@ -368,7 +379,7 @@ def monster_dead(i):
 
 #returns 1 if battle is finished, (one of the parties is dead) or 0 if not.
 def can_leave():
-	if g.hp <= 0:
+	if player.hp <= 0:
 		return 1
 	for i in range(len(monster_list)):
 		if monster_list[i].hp > 0:
@@ -387,7 +398,7 @@ def runaway():
 		#Attempt to run. Testers get better chance.
 		else:
 			if g.die_roll(1, 10+run_attempts) > 7 or \
-					(g.name == "testing123" and g.die_roll(1, 10) > 5):
+					(player.name == "testing123" and g.die_roll(1, 10) > 5):
 				window_battle.destroy()
 				main.print_message("You coward! You ran away from the "
 					+ monster.monster_groups[mon_index].name + ".")
@@ -425,26 +436,26 @@ def useitem():
 	#if item is healing
 	if item_type == 11:
 		#heal the player, delete the item
-		g.hp=g.hp + g.item.item[item_value].quality
+		player.hp=player.hp + g.item.item[item_value].quality
 		main.print_message("You are healed for " +
 					str(g.item.item[item_value].quality) + " health.")
 		g.item.drop_inv_item(g.item.find_inv_item(item_value))
-		if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
+		if player.hp >= player.adj_maxhp: player.hp = player.adj_maxhp
 		attack_player()
 
 	#if item is a gem
 	if item_type == 14:
 		global old_attack
-		old_attack = g.adj_attack
+		old_attack = player.adj_attack
 		gem_power = g.item.item[item_value].quality
 		#gem power increases attack strength potential
-		g.adj_attack = g.adj_attack + gem_power * 0.75
+		player.adj_attack = player.adj_attack + gem_power * 0.75
 		#gem power increases num_dice (ie. chance to hit and total damage)
 		global num_dice
 		num_dice = num_dice + gem_power/4
 		main.print_message("The " + g.item.item[item_value].name +
 			    " focuses the power of your attack.")
-		main.attack.set(g.adj_attack)
+		main.attack.set(player.adj_attack)
 		g.item.drop_inv_item(g.item.find_inv_item(item_value))
 		global used_gem
 		used_gem=1
@@ -458,16 +469,21 @@ def useitem():
 		if monster_list[sel_mon].hp > 0:
 			damage = int(g.item.item[item_value].quality)
 			g.item.drop_inv_item(g.item.find_inv_item(item_value))
-			if damage > 0:
-				main.print_message("The " + monster_list[sel_mon].name +
-					" is hit for " + str(damage) + " damage.")
-				monster_slashed(sel_mon)
-			monster_list[sel_mon].hp = monster_list[sel_mon].hp - damage
-			#you kill it?
-			if monster_list[sel_mon].hp <= 0:
-				monster_dead(sel_mon)
+			monster_hurt(sel_mon, damage)
 			if can_leave() == 0:
 				attack_player()
+
+	#If item is scripted:
+	if item_type == 15 or item_type == 17:
+		#If the scripting ends with an "end" command,
+		if action.activate_lines(g.xgrid, g.ygrid, g.zgrid,
+								g.item.item[item_value].scripting) == 1:
+			g.item.drop_inv_item(g.item.find_inv_item(item_value))
+		if can_leave() == 0:
+			attack_player()
+
+
+
 	if can_leave() == 1: return 0
 	refresh()
 
@@ -502,24 +518,24 @@ def useskill():
 	skill_index = g.findskill(skill_array_name[0])
 
 	#make sure we can use that skill, just in case. . .
-	if g.skill[skill_index][5] == 0 or g.skill[skill_index][2] > g.ep:
+	if player.skill[skill_index][5] == 0 or player.skill[skill_index][2] > player.ep:
 		return 0
 
 	#pay for the skill
-	g.ep = int(g.ep) - g.skill[skill_index][2]
+	player.ep = int(player.ep) - player.skill[skill_index][2]
 
 
 	#actually use the skill.
-	if g.skill[skill_index][1] == 0: #rage
+	if player.skill[skill_index][1] == 0: #rage
 		main.print_message("You fly into a rage.")
 		#increase attack ability
-		g.adj_attack += (1 + int(g.level)/4)
-		main.attack.set(g.adj_attack)
+		player.adj_attack += (1 + int(player.level)/4)
+		main.attack.set(player.adj_attack)
 		attack_player()
 
-	elif g.skill[skill_index][1] == 1: #Sneak away
+	elif player.skill[skill_index][1] == 1: #Sneak away
 		global run_attempts
-		if g.die_roll(1, 10 + int(g.level) + run_attempts) > 4:
+		if g.die_roll(1, 10 + int(player.level) + run_attempts) > 4:
 			main.print_message("You coward! You ran away from the " +
 				monster.monster_groups[mon_index].name + ".")
 			window_battle.destroy()
@@ -530,32 +546,26 @@ def useskill():
 			run_attempts += 3
 			main.print_message("You fail to sneak away.")
 			attack_player()
-	elif g.skill[skill_index][1] == 2: #Frenzy
+	elif player.skill[skill_index][1] == 2: #Frenzy
 		mon_num = select_monster()
-		for i in range(3 + int(g.level)/3):
+		for i in range(3 + int(player.level)/3):
 			if monster_list[mon_num].hp < 1:
 				mon_num = select_monster()
 			if mon_num == -1: return 0
-			attack_monster(mon_num)
+			attack_monster(mon_num, player.adj_attack)
 			if can_leave() == 1:
 				return 0
 			active_button = -1
 			monster_mouse_move()
 			refresh()
 		if can_leave() == 0: attack_player()
-	elif g.skill[skill_index][1] == 3: #Dismember
+	elif player.skill[skill_index][1] == 3: #Dismember
 		mon_num = select_monster()
 		if mon_num == -1: return 0
-		damage = (g.adj_attack * 5)/2
-		if damage > 0:
-			main.print_message("You hit the " + monster_list[mon_num].name +
-				" for " + str(damage) + " damage.")
-			monster_slashed(mon_num)
-		monster_list[mon_num].hp = monster_list[mon_num].hp - damage
-		#you kill it?
-		if monster_list[mon_num].hp <= 0:
-			monster_dead(mon_num)
-		attack_player()
+		damage = (player.adj_attack * 5)/2
+		monster_hurt(mon_num, damage)
+		if can_leave() == 0:
+			attack_player()
 
 	if can_leave() == 1: return 0
 	active_button = -1
@@ -583,7 +593,7 @@ def refresh_buttons():
 	else: canvas_buttons.create_image(attack_button_loc, 0, anchor=NW,
 					image=g.buttons["attack.png"])
 	if (cur_button == 1):
-		if g.hp <= 0:
+		if player.hp <= 0:
 			canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
 				image=g.buttons["quit_sel.png"])
 			help_text.set("Quit")
@@ -595,7 +605,7 @@ def refresh_buttons():
 			canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
 				image=g.buttons["leave_sel.png"])
 			help_text.set("Leave")
-	elif g.hp <= 0: canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
+	elif player.hp <= 0: canvas_buttons.create_image(run_button_loc, 0, anchor=NW,
 			image=g.buttons["quit.png"])
 	elif can_leave == 0:
 		canvas_buttons.create_image(run_button_loc,
@@ -887,7 +897,7 @@ def begin(mon_index_input):
 	global window_battle
 	global bgcolour
 	bgcolour = "lightgrey"
-	window_battle = Frame(main.top, bd=2, relief=SUNKEN, bg=bgcolour)
+	window_battle = Frame(main.top, bd=4, relief=GROOVE, bg=bgcolour)
 	window_battle.grid(row=1, column=5, columnspan=13, rowspan=13, sticky=E)
 	global mon_index
 	mon_index = mon_index_input
