@@ -19,7 +19,7 @@
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.45. Released under the GPL. Copyright 2005
+#Dragon Hunt 3.47. Released under the GPL. Copyright 2005
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
@@ -33,6 +33,10 @@ from os import path, mkdir, remove, walk
 
 #needed for scripting
 from scripting import *
+
+#player info
+from player import *
+
 import monster
 import item
 import main
@@ -41,25 +45,25 @@ import action
 #This will be displayed on the Title screen and Main screen.
 game_name = ""
 
-#general character stats
-name = ""
-hp = 0
-ep = 0
-maxhp = 0
-maxep = 0
-attack = 0
-defense = 0
-gold = 0
-exp = 0
-level = 0
-skillpoints = 1
-
-#stores attack/defense/hp/ep, adjusted by equipment.
-#kept correct by main.refreshmap(). Use these for calculations.
-adj_attack = 0
-adj_defense = 0
-adj_maxhp = 0
-adj_maxep = 0
+# #general character stats
+# name = ""
+# hp = 0
+# ep = 0
+# maxhp = 0
+# maxep = 0
+# attack = 0
+# defense = 0
+# gold = 0
+# exp = 0
+# level = 0
+# skillpoints = 1
+#
+# #stores attack/defense/hp/ep, adjusted by equipment.
+# #kept correct by main.refreshmap(). Use these for calculations.
+# adj_attack = 0
+# adj_defense = 0
+# adj_maxhp = 0
+# adj_maxep = 0
 
 #fill colour
 fill_colour = "#b9e5ad"
@@ -88,8 +92,8 @@ var_list = {}
 #of bombs from inv. UNUSED
 cur_mon_hp = 0
 
-#Name of current hero picture.
-cur_hero = "people/hero_w.png"
+# #Name of current hero picture.
+# cur_hero = "people/hero_w.png"
 
 #Current window in use (main, battle, inventory)
 cur_window = "main"
@@ -138,23 +142,23 @@ def savegame(save_file):
 	savefile=open(save_loc, 'w')
 	#savefile version; update whenever the data saved changes.
 	pickle.dump("dh3.3", savefile)
-	pickle.dump(name, savefile)
-	pickle.dump(hp, savefile)
-	pickle.dump(ep, savefile)
-	pickle.dump(maxhp, savefile)
-	pickle.dump(maxep, savefile)
-	pickle.dump(attack, savefile)
-	pickle.dump(defense, savefile)
-	pickle.dump(gold, savefile)
-	pickle.dump(exp, savefile)
-	pickle.dump(level, savefile)
-	pickle.dump(skillpoints, savefile)
+	pickle.dump(player.name, savefile)
+	pickle.dump(player.hp, savefile)
+	pickle.dump(player.ep, savefile)
+	pickle.dump(player.maxhp, savefile)
+	pickle.dump(player.maxep, savefile)
+	pickle.dump(player.attack, savefile)
+	pickle.dump(player.defense, savefile)
+	pickle.dump(player.gold, savefile)
+	pickle.dump(player.exp, savefile)
+	pickle.dump(player.level, savefile)
+	pickle.dump(player.skillpoints, savefile)
 
 	#equipment is stored by name to increase savefile compatability.
-	pickle.dump(len(item.equip), savefile)
-	for i in range(len(item.equip)):
-		if item.equip[i] != -1:
-			pickle.dump(item.item[item.equip[i]].name, savefile)
+	pickle.dump(len(player.equip), savefile)
+	for i in range(len(player.equip)):
+		if player.equip[i] != -1:
+			pickle.dump(item.item[player.equip[i]].name, savefile)
 		else: pickle.dump("Ignore", savefile)
 	pickle.dump(len(item.inv), savefile)
 	for i in range(len(item.inv)):
@@ -166,13 +170,13 @@ def savegame(save_file):
 	pickle.dump(zgrid, savefile)
 	#skills are stored by name as well.
 	num = 0
-	for i in range(len(skill)):
-		if skill[i][5] == 1:
+	for i in range(len(player.skill)):
+		if player.skill[i][5] == 1:
 			num += 1
 	pickle.dump(num, savefile)
-	for i in range(len(skill)):
-		if skill[i][5] == 1:
-			pickle.dump(skill[i][0], savefile)
+	for i in range(len(player.skill)):
+		if player.skill[i][5] == 1:
+			pickle.dump(player.skill[i][0], savefile)
 
 	pickle.dump(item.dropped_items, savefile)
 	pickle.dump(timestep, savefile)
@@ -185,24 +189,24 @@ def loadgame(save_file):
 	version = pickle.load(savefile)
 	if version != "dh3.3":
 		return loadgame_31(save_file)
-	global name;		name = pickle.load(savefile)
-	global hp;			hp = pickle.load(savefile)
-	global ep;			ep = pickle.load(savefile)
-	global maxhp;		maxhp = pickle.load(savefile)
-	global maxep;		maxep = pickle.load(savefile)
-	global attack;		attack = pickle.load(savefile)
-	global defense;		defense = pickle.load(savefile)
-	global gold;		gold = pickle.load(savefile)
-	global exp;			exp = pickle.load(savefile)
-	global level;		level = pickle.load(savefile)
-	global skillpoints;	skillpoints = pickle.load(savefile)
+	player.name = pickle.load(savefile)
+	player.hp = pickle.load(savefile)
+	player.ep = pickle.load(savefile)
+	player.maxhp = pickle.load(savefile)
+	player.maxep = pickle.load(savefile)
+	player.attack = pickle.load(savefile)
+	player.defense = pickle.load(savefile)
+	player.gold = pickle.load(savefile)
+	player.exp = pickle.load(savefile)
+	player.level = pickle.load(savefile)
+	player.skillpoints = pickle.load(savefile)
 
 	#equipment is stored by name to increase savefile compatability.
-	global equip;		equip_len = pickle.load(savefile)
+	equip_len = pickle.load(savefile)
 	for i in range(equip_len):
-		item.equip[i] = item.finditem(pickle.load(savefile))
-		if item.item[item.equip[i]].name == "Ignore":
-			item.equip[i] = -1
+		player.equip[i] = item.finditem(pickle.load(savefile))
+		if item.item[player.equip[i]].name == "Ignore":
+			player.equip[i] = -1
 	global inv;			inv_len = pickle.load(savefile)
 	for i in range(inv_len):
 		item.inv[i] = item.finditem(pickle.load(savefile))
@@ -211,9 +215,9 @@ def loadgame(save_file):
 	global xgrid;		xgrid = pickle.load(savefile)
 	global ygrid;		ygrid = pickle.load(savefile)
 	global zgrid;		zgrid = pickle.load(savefile)
-	global skill;		skill_len = pickle.load(savefile)
+	skill_len = pickle.load(savefile)
 	for i in range(skill_len):
-		skill[findskill(pickle.load(savefile))][5] = 1
+		player.skill[findskill(pickle.load(savefile))][5] = 1
 	item.dropped_items = pickle.load(savefile)
 	global timestep;	timestep = pickle.load(savefile)
 	global var_list;	var_list = pickle.load(savefile)
@@ -224,26 +228,26 @@ def loadgame_31(save_file):
 	savefile=open(save_loc, 'r')
 	version = pickle.load(savefile)
 	if version != "dh3.2":
-		print "old savefile version"
+		print "Old savefile version. Try an earlier version of DH."
 		return -1
-	global name;		name = pickle.load(savefile)
-	global hp;			hp = pickle.load(savefile)
-	global ep;			ep = pickle.load(savefile)
-	global maxhp;		maxhp = pickle.load(savefile)
-	global maxep;		maxep = pickle.load(savefile)
-	global attack;		attack = pickle.load(savefile)
-	global defense;		defense = pickle.load(savefile)
-	global gold;		gold = pickle.load(savefile)
-	global exp;			exp = pickle.load(savefile)
-	global level;		level = pickle.load(savefile)
-	global skillpoints;	skillpoints = pickle.load(savefile)
+	player.name = pickle.load(savefile)
+	player.hp = pickle.load(savefile)
+	player.ep = pickle.load(savefile)
+	player.maxhp = pickle.load(savefile)
+	player.maxep = pickle.load(savefile)
+	player.attack = pickle.load(savefile)
+	player.defense = pickle.load(savefile)
+	player.gold = pickle.load(savefile)
+	player.exp = pickle.load(savefile)
+	player.level = pickle.load(savefile)
+	player.skillpoints = pickle.load(savefile)
 
 	#equipment is stored by name to increase savefile compatability.
-	global equip;		equip_len = pickle.load(savefile)
+	equip_len = pickle.load(savefile)
 	for i in range(equip_len):
-		item.equip[i] = item.finditem(pickle.load(savefile))
-		if item.item[item.equip[i]].name == "Ignore":
-			item.equip[i] = -1
+		player.equip[i] = item.finditem(pickle.load(savefile))
+		if item.item[player.equip[i]].name == "Ignore":
+			player.equip[i] = -1
 	global inv;			inv_len = pickle.load(savefile)
 	for i in range(inv_len):
 		item.inv[i] = item.finditem(pickle.load(savefile))
@@ -252,9 +256,9 @@ def loadgame_31(save_file):
 	global xgrid;		xgrid = pickle.load(savefile)
 	global ygrid;		ygrid = pickle.load(savefile)
 	global zgrid;		zgrid = pickle.load(savefile)
-	global skill;		skill_len = pickle.load(savefile)
+	skill_len = pickle.load(savefile)
 	for i in range(skill_len):
-		skill[findskill(pickle.load(savefile))][5] = 1
+		player.skill[findskill(pickle.load(savefile))][5] = 1
 	global timestep;	timestep = pickle.load(savefile)
 	global cur_mon_hp;	cur_mon_hp = pickle.load(savefile)
 	savefile.close()
@@ -408,40 +412,40 @@ def read_perturn():
 				per_turn_script[turn_num].append(line)
 
 
-#skills array. Each skill is a separate line in the array. Each line goes:
-#name, effect, level, price, description, acquired
-#effect is an integer that tells battle.py which case in a select to pick.
-#level is the skillpoints required to get the skill,
-#as well as the ep needed to use.
-#acquired tells if the skill has already been learned by the player.
-skill = []
+# #skills array. Each skill is a separate line in the array. Each line goes:
+# #name, effect, level, price, description, acquired
+# #effect is an integer that tells battle.py which case in a select to pick.
+# #level is the skillpoints required to get the skill,
+# #price is the ep needed to use.
+# #acquired tells if the skill has already been learned by the player.
+# skill = []
 
 #Add a skill to the skill[] array
 def addskill(name, effect, level, price, description):
-	skill.append([])
-	i = len(skill)
-	skill[i-1].append(name)
-	skill[i-1].append(effect)
-	skill[i-1].append(level)
-	skill[i-1].append(price)
-	skill[i-1].append(description)
-	skill[i-1].append(0)
+	player.skill.append([])
+	i = len(player.skill)
+	player.skill[i-1].append(name)
+	player.skill[i-1].append(effect)
+	player.skill[i-1].append(level)
+	player.skill[i-1].append(price)
+	player.skill[i-1].append(description)
+	player.skill[i-1].append(0)
 
 
 #takes a skill name, and returns its location in the
 #skill[] array, with -1 == nonexisting.
 def findskill(name):
-	for i in range(len(skill)):
-		if name.lower() == skill[i][0].lower():
+	for i in range(len(player.skill)):
+		if name.lower() == player.skill[i][0].lower():
 			return i
 	return -1
 
 #gives the player a skill; takes the location in skill[] as input
 def add_skill(skill_loc):
-	if (skill[skill_loc][5] == 1):
+	if (player.skill[skill_loc][5] == 1):
 		return 0
 	else:
-		skill[skill_loc][5] = 1
+		player.skill[skill_loc][5] = 1
 		return 1
 
 #add skills. I really should change these to scripts sometime.
@@ -454,18 +458,6 @@ addskill("Dismember",  3, 2, 20,
 addskill("Frenzy",  2, 2, 30,
 	"Your next attack will try to hit more than once")
 
-#Gives the player the specified amount of experience; also handles level gains.
-def add_exp(input_exp):
-	global exp
-	global level
-	exp = int(exp) + int(input_exp)
-	#Has the player gained a level?
-	if int(exp) >= int(10*(level + 1)*(level + 1)):
-		level=level+1
-		main.print_message("You gain a level.")
-		action.activate_lines(xgrid, ygrid, zgrid, levelup_act)
-
-
 
 #Rolls dice in the form 2d6, where 2 is the number of dice, and 6 the number of
 #sides on each die. modify is the bonus given to each die. Use die_roll(2, 6)
@@ -554,34 +546,35 @@ def load_buttons():
 		buttons[image_name] = image
 
 
-#given a filename, return the script contained in the file.
-#Deals with comments, empty lines, and line-continuation.
-def read_script_file(file_name):
+#given a filename, return the script contained in the file. dont_interpret will
+#be used for the map editor, to keep it from shredding formatting.
+def read_script_file(file_name, from_editor=0):
 	temp_array = []
 	file = open(g.mod_directory + file_name, 'r')
-
-	#go through all lines of the file
-	file_line = file.readline()
-	while file_line != '':
-		#strip out spaces/tabs
-		file_line = file_line.strip()
-
-		#ignore blank lines and comments
-		if file_line[:1] == "#" or file_line[:1] == "":
-			file_line = file.readline()
-			continue
-
-		#allow the \ line-continuation character.
-		while file_line[-1:] == "\\":  #really a single backslash, BTW.
-			file_line = file_line[:-1] + file.readline()[:-1]
-			file_line = file_line.strip()
-
-		temp_array.append(file_line)
-
-		#ready another line
-		file_line = file.readline()
-
+	temp_array.extend(file.readlines())
 	file.close()
+	if from_editor==0:
+		temp_array = interpret_lines(temp_array)
+	return temp_array
+
+#Takes an array of lines, and deals with comments, empty lines,
+#and line-continuation, to properly interpret the scripting.
+def interpret_lines(temp_array):
+	cur_line = 0
+	while 1:
+		if cur_line >= len(temp_array): break
+		#strip out spaces/tabs
+		temp_array[cur_line] = temp_array[cur_line].strip()
+		#ignore blank lines and comments
+		if temp_array[cur_line][:1] == "#" or temp_array[cur_line] == "":
+			temp_array.pop(cur_line)
+			continue
+		#allow the \ line-continuation character.
+		while temp_array[cur_line][-1:] == "\\":  #really a single backslash, BTW.
+			temp_array[cur_line] = temp_array[cur_line][:-1] + temp_array[cur_line+1][:-1]
+			temp_array.pop(cur_line+1)
+			temp_array[cur_line].strip()
+		cur_line += 1
 	return temp_array
 
 #given a directory relative to g.mod_directory, will return a dictionary
