@@ -29,11 +29,16 @@ import action
 import re
 import item
 
+from player import *
+
 #width/height of inv canvas, in tiles.
 # (g.tilesize + the 3 pixel border)
 inv_width = 4
 inv_height = 7
 
+#width/height of the equipment canvas, in tiles.
+equip_size = 3
+
 #Currently selected item number
 curr_item = 0
 
@@ -68,7 +73,7 @@ leave_height = 0
 #called when "Save" is pressed
 def inv_savegame():
 	if action.has_dialog == 1: return 0
-	g.savegame(g.name)
+	g.savegame(player.name)
 	main.print_message("** Game Saved **")
 	help_text.set("Game Saved")
 
@@ -84,14 +89,22 @@ def leave_inv():
 #puts a worn item into the inventory. Called from the remove button.
 def rm_equip():
 	if action.has_dialog == 1: return 0
-	if (len(listbox_equip.curselection()) > 0):
-		try: item_num = map(int, listbox_equip.curselection())
-		except ValueError: pass
-		if item.equip[item_num[0]] != -1:
-			if -1 != item.take_inv_item(item.equip[item_num[0]]):
-				main.print_message("You take off your " +
-					item.item[item.equip[item_num[0]]].name)
-				item.equip[item_num[0]] = -1
+	#Curr_item is the current location in the equipment canvas.
+	#The missing numbers in this sequence are the blank spots in the display.
+	sel_equipment = -1
+	if curr_item == 1: sel_equipment = 3
+	elif curr_item == 2: sel_equipment = 4
+	elif curr_item == 3: sel_equipment = 0
+	elif curr_item == 4: sel_equipment = 1
+	elif curr_item == 5: sel_equipment = 2
+	elif curr_item == 7: sel_equipment = 5
+	if sel_equipment == -1: return 0
+
+	if player.equip[sel_equipment] != -1:
+		if -1 != item.take_inv_item(player.equip[sel_equipment]):
+			main.print_message("You take off your " +
+				item.item[player.equip[sel_equipment]].name)
+			player.equip[sel_equipment] = -1
 	refresh_inv()
 
 #takes an item from the inventory, and wears it.
@@ -109,12 +122,12 @@ def wear_item():
 	#if item is equipment
 	if item_loc < 6:
 		#trade the item and whatever's in the equip slot
-		temp = item.equip[item_loc]
-		item.equip[item_loc] = item_value
+		temp = player.equip[item_loc]
+		player.equip[item_loc] = item_value
 		item.drop_inv_item(curr_item)
 		item.take_inv_item(temp)
 		main.print_message("You equip yourself with your " +
-			item.item[item.equip[item_loc]].name + ".")
+			item.item[player.equip[item_loc]].name + ".")
 		refresh_inv()
 
 #drops an item from the inventory. Uses curr_item
@@ -125,7 +138,8 @@ def drop_item():
 	try: item_to_delete = item.find_inv_item(item.inv[curr_item])
 	except IndexError: return 0
 
-	if item.item[item.inv[item_to_delete]].price == 0:
+	if item.item[item.inv[item_to_delete]].price == 0 and \
+				item.item[item.inv[item_to_delete]].value == 0:
 		main.print_message("You feel attached to your " +
 			item.item[item.inv[item_to_delete]].name)
 		return 0
@@ -242,9 +256,13 @@ def use_item():
 	#if item is healing
 	if item_loc == 11:
 		#heal the player, delete the item
-		g.hp=g.hp + item.item[item_value].quality
+		player.hp=player.hp + item.item[item_value].quality
 		item.drop_inv_item(curr_item)
-		if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
+		if player.hp >= player.adj_maxhp: player.hp = player.adj_maxhp
+	if item_loc == 16 or item_loc == 17:
+		if action.activate_lines(g.xgrid, g.ygrid, g.zgrid,
+										item.item[item_value].scripting) == 1:
+			item.drop_inv_item(curr_item)
 
 	refresh_inv()
 
@@ -310,67 +328,68 @@ def refresh_buttons(event=0):
 #refresh this screen. Call after moving around items.
 def refresh_inv():
 	if action.has_dialog == 1: return 0
-	#place current position into item_num[0], for restoring position.
 	canvas_inv.delete("item")
-	invpos = 0
+# 	invpos = 0
 	#if the inv is selected, draw a selection box around the current item.
-	if (curr_item != -1):
-		canvas_inv.create_rectangle(
-			(curr_item%inv_width)*g.tilesize + 2 * ((curr_item%inv_width)+1),
-			(curr_item/inv_width)*g.tilesize + 2 * ((curr_item/inv_width)+1),
-			((curr_item%inv_width)+1)*(g.tilesize + 2),
-			((curr_item/inv_width)+1)*(g.tilesize + 2), fill=g.fill_sel_colour, tags="item")
+	if cur_button == 0 or (cur_button == 1):
+		if (curr_item != -1):
+			canvas_inv.create_rectangle(
+				(curr_item%inv_width)*g.tilesize + 2 * ((curr_item%inv_width)+1),
+				(curr_item/inv_width)*g.tilesize + 2 * ((curr_item/inv_width)+1),
+				((curr_item%inv_width)+1)*(g.tilesize + 2),
+				((curr_item/inv_width)+1)*(g.tilesize + 2), fill=g.fill_sel_colour, tags="item")
 
 	#draw the item pictures.
 	for i in range(len(item.inv)):
 		if item.inv[i] != -1:
-			canvas_inv.create_image((i%inv_width)*g.tilesize + 2 * ((i%inv_width)+1),
-				(i/inv_width)*g.tilesize + 2 * ((i/inv_width)+1),
-				image=g.tiles[item.item[item.inv[i]].picturename],
-				anchor="nw", tags="item")
-			invpos += 1
+			draw_item(canvas_inv, item.item[item.inv[i]].picturename,
+						i%inv_width, i/inv_width)
+# 			invpos += 1
 
-	try: equip_num = map(int, listbox_equip.curselection())
-	except ValueError: pass
+	canvas_equip.delete("item")
+	if cur_button == 3: #equipment
+		canvas_equip.create_rectangle(
+			(curr_item%equip_size)*g.tilesize + 2 * ((curr_item%equip_size)+1),
+			(curr_item/equip_size)*g.tilesize + 2 * ((curr_item/equip_size)+1),
+			((curr_item%equip_size)+1)*(g.tilesize + 2),
+			((curr_item/equip_size)+1)*(g.tilesize + 2), fill=g.fill_sel_colour, tags="item")
 
 	#rebuild the equipment display
-	listbox_equip.delete(0, END)
-	temp = item.item[item.equip[0]].name
-	if item.equip[0] == -1: temp = ""
-	listbox_equip.insert(END, "Weapon: " + temp)
 
-	temp = item.item[item.equip[1]].name
-	if item.equip[1] == -1: temp = ""
-	listbox_equip.insert(END, "Armor: " + temp)
+	#Weapon
+	if player.equip[0] != -1:
+		draw_item(canvas_equip, item.item[player.equip[0]].picturename, 0, 1)
+	else: draw_item(canvas_equip, "items/weapon_eq.png", 0, 1)
+	#Armor
+	if player.equip[1] != -1:
+		draw_item(canvas_equip, item.item[player.equip[1]].picturename, 1, 1)
+	else: draw_item(canvas_equip, "items/armor_eq.png", 1, 1)
+	#Shield
+	if player.equip[2] != -1:
+		draw_item(canvas_equip, item.item[player.equip[2]].picturename, 2, 1)
+	else: draw_item(canvas_equip, "items/shield_eq.png", 2, 1)
+	#Helmet
+	if player.equip[3] != -1:
+		draw_item(canvas_equip, item.item[player.equip[3]].picturename, 1, 0)
+	else: draw_item(canvas_equip, "items/helmet_eq.png", 1, 0)
+	#Gloves
+	if player.equip[4] != -1:
+		draw_item(canvas_equip, item.item[player.equip[4]].picturename, 2, 0)
+	else: draw_item(canvas_equip, "items/gloves_eq.png", 2, 0)
+	#Boots
+	if player.equip[5] != -1:
+		draw_item(canvas_equip, item.item[player.equip[5]].picturename, 1, 2)
+	else: draw_item(canvas_equip, "items/boots_eq.png", 1, 2)
 
-	temp = item.item[item.equip[2]].name
-	if item.equip[2] == -1: temp = ""
-	listbox_equip.insert(END, "Shield: " + temp)
-
-	temp = item.item[item.equip[3]].name
-	if item.equip[3] == -1: temp = ""
-	listbox_equip.insert(END, "Helmet: " + temp)
-
-	temp = item.item[item.equip[4]].name
-	if item.equip[4] == -1: temp = ""
-	listbox_equip.insert(END, "Gloves: " + temp)
-
-	temp = item.item[item.equip[5]].name
-	if item.equip[5] == -1: temp = ""
-	listbox_equip.insert(END, "Boots: " + temp)
-
-	#restore the position.
-	if (cur_button == 3): #equipment
-		try:
-			if (equip_num[0] < listbox_equip.size()):
-				listbox_equip.selection_set(equip_num[0])
-			else:
-				if (listbox_equip.size() > 0):
-					listbox_equip.selection_set(equip_num[0] - 1)
-		except IndexError:
-			listbox_equip.selection_set(0)
 	main.recalc_stats()
 
+#Takes a canvas, a string (leading to a picture in g.tiles[]), and xy coords
+#(in tiles, starting from 0), and draws the picture.
+def draw_item(input_canvas, input_picture, x, y):
+	input_canvas.create_image(x*g.tilesize + 2*(x+1),
+				y*g.tilesize + 2*(y+1),
+				image=g.tiles[input_picture],
+				anchor="nw", tags="item")
 
 #All keypresses in window_inv pass through here. Based on the key name,
 #give the right action. ("etc", "left", "right", "up", "down", "return")
@@ -392,11 +411,10 @@ def key_handler(key_name):
 			curr_item = 3
 		elif (cur_button == 3): #switch from remove to save
 			cur_button = 2
-			listbox_equip.select_clear(0, END)
+			curr_item = -1
 		elif (cur_button == 4): #switch from quit to remove
 			cur_button = 3
-			if (len(listbox_equip.curselection()) == 0):
-				listbox_equip.selection_set(0)
+			curr_item = 0
 	elif (key_name == "pgdn"):
 		if (cur_button == 0): #switch from drop to use
 			cur_button = 1
@@ -405,11 +423,10 @@ def key_handler(key_name):
 			curr_item = -1
 		elif (cur_button == 2): #switch from save to remove
 			cur_button = 3
-			if (len(listbox_equip.curselection()) == 0):
-				listbox_equip.selection_set(0)
+			curr_item = 0
 		elif (cur_button == 3): #switch from remove to quit
 			cur_button = 4
-			listbox_equip.select_clear(0, END)
+			curr_item = -1
 		elif (cur_button == 4): #switch from quit to drop
 			cur_button = 0
 			curr_item = 0
@@ -425,11 +442,12 @@ def key_handler(key_name):
 			else: curr_item += 1
 		elif (cur_button == 2): #switch from save to remove
 			cur_button = 3
-			if (len(listbox_equip.curselection()) == 0):
-				listbox_equip.selection_set(0)
-		elif (cur_button == 3): #switch from remove to quit
-			cur_button = 4
-			listbox_equip.select_clear(0, END)
+			curr_item = 0
+		elif (cur_button == 3): #Move right, or switch from remove to quit
+			if (curr_item % equip_size == equip_size-1):  #if on right side
+				cur_button = 4
+				curr_item = -1
+			else: curr_item += 1
 		elif (cur_button == 4): #switch from quit to drop
 			cur_button = 0
 			curr_item = 0
@@ -446,45 +464,32 @@ def key_handler(key_name):
 		elif (cur_button == 2): #switch from save to use
 			cur_button = 1
 			curr_item = 3
-		elif (cur_button == 3): #switch from remove to save
-			cur_button = 2
-			listbox_equip.select_clear(0, END)
+		elif (cur_button == 3): #move left, or switch from remove to save
+			if (curr_item % equip_size == 0):  #if on left side
+				cur_button = 2
+				curr_item = -1
+			else: curr_item -= 1
 		elif (cur_button == 4): #switch from quit to remove
 			cur_button = 3
-			if (len(listbox_equip.curselection()) == 0):
-				listbox_equip.selection_set(0)
+			curr_item = equip_size -1
 	elif (key_name == "up"):
 		if (cur_button == 0 or cur_button == 1): #if in inv
 			curr_item = curr_item - inv_width
 			if curr_item < 0:
 				curr_item += inv_width * inv_height
 		if (cur_button == 3): #if in equip
-			try:
-				try: item_num = map(int, listbox_equip.curselection())
-				except ValueError: pass
-				if (item_num[0] != 0):
-					listbox_equip.select_clear(0, END)
-					listbox_equip.selection_set(item_num[0] - 1)
-				else:
-					listbox_equip.select_clear(0, END)
-					listbox_equip.selection_set(END)
-			except IndexError: pass
+			curr_item = curr_item - equip_size
+			if curr_item < 0:
+				curr_item += equip_size * equip_size
 	elif (key_name == "down"):
 		if (cur_button == 0 or cur_button == 1): #if in inv
 			curr_item = curr_item + inv_width
 			if curr_item >= inv_width * inv_height:
 				curr_item -= inv_width * inv_height
 		if (cur_button == 3): #if in equip
-			try: item_num = map(int, listbox_equip.curselection())
-			except ValueError: pass
-			try:
-				if (item_num[0] != listbox_equip.size() - 1):
-					listbox_equip.select_clear(0, END)
-					listbox_equip.selection_set(item_num[0] + 1)
-				else:
-					listbox_equip.select_clear(0, END)
-					listbox_equip.selection_set(0)
-			except IndexError: pass
+			curr_item = curr_item + equip_size
+			if curr_item >= equip_size * equip_size:
+				curr_item -= equip_size * equip_size
 	elif (key_name == "return"):
 		if (cur_button == 0): drop_item()
 		elif (cur_button == 1):
@@ -514,7 +519,7 @@ def mouse_handler_click(event=0):
 
 #Used in mouse_sel_inv. Takes x y coordinates, and returns
 #the selected box, or -1 for none.
-def which_box(x, y):
+def which_box(x, y, temp_size):
 	if x < 3: return -1
 	tempx = x - 3
 	likelyx = tempx / (g.tilesize + 2)
@@ -527,34 +532,48 @@ def which_box(x, y):
 	tempy = tempy - (likelyy * (g.tilesize + 2))
 	if tempy >= g.tilesize - 1: return -1
 
-	return likelyy * inv_width + likelyx
+	return likelyy * temp_size + likelyx
 
 #called when the user releases the mouse in the inv canvas.
 def mouse_sel_inv(event=0):
 	#decide if the mouse is within one of the boxes.
 	global curr_item
 	#global curr_focus
-	temp_num =  which_box(event.x, event.y)
+	temp_num =  which_box(event.x, event.y, inv_width)
 	if temp_num == -1: return
 	curr_item = temp_num
-	#curr_focus = 0
+	global cur_button
+	if cur_button != 0 and cur_button != 1:
+		cur_button = 1
+	refresh_buttons()
+	refresh_inv()
+
+#called when the user releases the mouse in the equip canvas.
+def mouse_sel_equip(event=0):
+	#decide if the mouse is within one of the boxes.
+	global curr_item
+	temp_num =  which_box(event.x, event.y, equip_size)
+	if temp_num == -1: return
+	curr_item = temp_num
+	global cur_button
+	cur_button = 3
+	refresh_buttons()
 	refresh_inv()
-	#show_details()
 
 def mouse_handler_move(event=0):
 	if action.has_dialog == 1: return 0
 	global cur_button
 	if (event.x < use_height):
 		cur_button = 0
-		listbox_equip.select_clear(0, END)
+# 		listbox_equip.select_clear(0, END)
 	elif (event.x < save_height):
 		cur_button = 1
-		listbox_equip.select_clear(0, END)
+# 		listbox_equip.select_clear(0, END)
 	elif (event.x < remove_height): cur_button = 2
 	elif (event.x < leave_height):
 		cur_button = 3
-		if (len(listbox_equip.curselection()) == 0):
-			listbox_equip.selection_set(0)
+# 		if (len(listbox_equip.curselection()) == 0):
+# 			listbox_equip.selection_set(0)
 	else: cur_button = 4
 	refresh_buttons()
 
@@ -563,7 +582,7 @@ def init_window_inv():
 	global window_inv
 	global bgcolour
 	bgcolour = "lightgrey"
-	window_inv = Frame(main.top, bd=2, relief=SUNKEN, bg=bgcolour)
+	window_inv = Frame(main.top, bd=4, relief=GROOVE, bg=bgcolour)
 	window_inv.grid(row=1, column=5, columnspan=13, rowspan=13, sticky=E)
 	global curr_item
 	curr_item = 0
@@ -588,9 +607,25 @@ def init_window_inv():
 										(x+1)*(g.tilesize + 2),
 										(y+1)*(g.tilesize + 2), fill=g.fill_colour)
 
-	global listbox_equip
-	listbox_equip = Listbox(window_inv, height=10, takefocus=0, bg=bgcolour)
-	listbox_equip.grid(row=2, column=2, rowspan=10, sticky=N+W+E)
+
+	#Equipment canvas
+	temp_canvas_width=(g.tilesize*equip_size)+ 9
+	global canvas_equip
+	canvas_equip = Canvas(window_inv, width=temp_canvas_width,
+		height=temp_canvas_width, highlightthickness=0, bg=g.outline_colour)
+	canvas_equip.grid(column=2, row=2, rowspan=10)
+	canvas_equip.create_rectangle(0,0, temp_canvas_width-1, temp_canvas_width-1)
+	#per-item borders
+	for y in range(equip_size):
+		for x in range(equip_size):
+			canvas_equip.create_rectangle(x*g.tilesize + 2 * (x+1),
+										y*g.tilesize + 2 * (y+1),
+										(x+1)*(g.tilesize + 2),
+										(y+1)*(g.tilesize + 2), fill=g.fill_colour)
+
+# 	global listbox_equip
+# 	listbox_equip = Listbox(window_inv, height=10, takefocus=0, bg=bgcolour)
+# 	listbox_equip.grid(row=2, column=2, rowspan=10, sticky=N+W+E)
 
 
 	#Location of the various buttons. Note that these are *_height, but
@@ -622,6 +657,7 @@ def init_window_inv():
 #bind the keys. Called upon window creation and return from a yes/no box
 def bind_keys():
 	canvas_inv.bind("<ButtonRelease-1>",  mouse_sel_inv)
+	canvas_equip.bind("<ButtonRelease-1>",  mouse_sel_equip)
 	main.window_main.bind(g.binding_cancel, key_handler_esc)
 	main.window_main.bind(g.binding_action, key_handler_return)
 	main.window_main.bind(g.binding_up, key_handler_up)
