@@ -30,6 +30,15 @@ global cur_button
 cur_button = 0
 
 help_text = StringVar()
+name_text = StringVar()
+hp_text = StringVar()
+ep_text = StringVar()
+attack_text = StringVar()
+defense_text = StringVar()
+gold_text = StringVar()
+exp_text = StringVar()
+level_text = StringVar()
+
 
 #called when "Load" is pressed
 def load_selected():
@@ -43,6 +52,32 @@ def load_selected():
 	did_load = 1
 	window_loadgame.destroy()
 
+#Uses the current position of listbox_saves to display infomation about
+#that save.
+def refresh_save_info(event=0):
+	#This is the bad way to do this, as it needs updating whenever the
+	#save format changes significantly.
+	if (listbox_saves.size() == 0): return
+	#find the name of the save to load
+	try: item_num = map(int, listbox_saves.curselection())
+	except ValueError: pass
+	save_title = listbox_saves.get(item_num[0])
+
+	save_loc = g.mod_directory + "/saves/" + save_title
+	savefile=open(save_loc, 'r')
+	version_unused = g.pickle.load(savefile)
+	name_text.set(g.pickle.load(savefile))
+	hp_text.set(g.pickle.load(savefile))
+	ep_text.set(g.pickle.load(savefile))
+	unused_maxhp = g.pickle.load(savefile)
+	unused_maxep = g.pickle.load(savefile)
+	attack_text.set(g.pickle.load(savefile))
+	defense_text.set(g.pickle.load(savefile))
+	gold_text.set(g.pickle.load(savefile))
+	exp_text.set(g.pickle.load(savefile))
+	level_text.set(g.pickle.load(savefile))
+	savefile.close()
+
 
 #All keypresses in window_shop pass through here. Based on the key name,
 #give the right action. ("etc", "left", "right", "up", "down", "return")
@@ -63,6 +98,7 @@ def key_handler(switch):
 		else:
 			listbox_saves.select_clear(0, END)
 			listbox_saves.selection_set(END)
+		refresh_save_info()
 	elif (switch == "down"):
 		if (listbox_saves.size() == 0): return
 		try: item_num = map(int, listbox_saves.curselection())
@@ -73,6 +109,7 @@ def key_handler(switch):
 		else:
 			listbox_saves.select_clear(0, END)
 			listbox_saves.selection_set(0)
+		refresh_save_info()
 	elif (switch == "return"):
 		if cur_button == 0: load_selected()
 		else: cancel_load()
@@ -134,6 +171,43 @@ def init_window_loadgame():
 	scroll_saves.grid(row=1, column=5, rowspan=10, sticky="NSE")
 	listbox_saves.config(yscrollcommand=scroll_saves.set)
 
+	label_formatting = Label(window_loadgame, text="Name:")
+	label_formatting.grid(row=1, column=6, sticky=E)
+	label_formatting = Label(window_loadgame, text="hp:")
+	label_formatting.grid(row=2, column=6, sticky=E)
+	label_formatting = Label(window_loadgame, text="ep:")
+	label_formatting.grid(row=3, column=6, sticky=E)
+	label_formatting = Label(window_loadgame, text="attack:")
+	label_formatting.grid(row=4, column=6, sticky=E)
+	label_formatting = Label(window_loadgame, text="defense:")
+	label_formatting.grid(row=5, column=6, sticky=E)
+	label_formatting = Label(window_loadgame, text="gold:")
+	label_formatting.grid(row=6, column=6, sticky=E)
+	label_formatting = Label(window_loadgame, text="exp:")
+	label_formatting.grid(row=7, column=6, sticky=E)
+	label_formatting = Label(window_loadgame, text="level:")
+	label_formatting.grid(row=8, column=6, sticky=E)
+
+	label_name = Label(window_loadgame, textvar=name_text)
+	label_name.grid(row=1, column=7, sticky=W)
+	label_hp = Label(window_loadgame, textvar=hp_text)
+	label_hp.grid(row=2, column=7, sticky=W)
+	label_ep = Label(window_loadgame, textvar=ep_text)
+	label_ep.grid(row=3, column=7, sticky=W)
+	label_attack = Label(window_loadgame, textvar=attack_text)
+	label_attack.grid(row=4, column=7, sticky=W)
+	label_defense = Label(window_loadgame, textvar=defense_text)
+	label_defense.grid(row=5, column=7, sticky=W)
+	label_gold= Label(window_loadgame, textvar=gold_text)
+	label_gold.grid(row=6, column=7, sticky=W)
+	label_exp = Label(window_loadgame, textvar=exp_text)
+	label_exp.grid(row=7, column=7, sticky=W)
+	label_level = Label(window_loadgame, textvar=level_text)
+	label_level.grid(row=8, column=7, sticky=W)
+
+	label_formatting = Label(window_loadgame, text="                    ")
+	label_formatting.grid(row=0, column=7, sticky=E)
+
 	global label_help
 	label_help = Label(window_loadgame, textvariable=help_text)
 	label_help.grid(row=0, column=4, columnspan=2, sticky=EW)
@@ -159,7 +233,7 @@ def init_window_loadgame():
 	#show the files contained in the saves directory.
 	array_save = listdir(g.mod_directory + "/saves")
 	for i in array_save:
-		if i[:1] != ".":
+		if i[:1] != "." and i != "CVS":
 			listbox_saves.insert(END, i)
 
 	listbox_saves.select_set(0)
@@ -174,7 +248,9 @@ def init_window_loadgame():
 	window_loadgame.bind("<Down>", key_handler_down)
 	window_loadgame.bind("<Return>", key_handler_return)
 	listbox_saves.bind("<Double-Button-1>", key_handler_return)
+	listbox_saves.bind("<ButtonRelease-1>", refresh_save_info)
 	refresh_buttons()
+	refresh_save_info()
 
 	window_loadgame.master.wait_window(window_loadgame)
 	return did_load
