@@ -37,6 +37,8 @@ import battle
 import shop
 import action
 
+from player import *
+
 #size, in tiles, of the main screen. While this is adjustable,
 #odd numbers would work much better. (To keep the player centered.)
 mapsizex = 19
@@ -96,13 +98,13 @@ def print_message(message):
 #save game
 def save_game(event=0):
 	if action.has_dialog == 1: return 0
-	g.savegame(g.name)
+	g.savegame(player.name)
 	print_message("** Game Saved **");
 
 #determine if the player is dead, and, if so, end the game.
 def dead_yet():
 	#did you die?
-	if g.hp <= 0:
+	if player.hp <= 0:
 		action.activate_line(g.xgrid, g.ygrid, g.zgrid, "die")
 		return 1
 	return 0
@@ -110,20 +112,20 @@ def dead_yet():
 #back to main menu. Called on death.
 def close_window(event=0):
 	if action.has_dialog == 1: return
-	if canvas_map.winfo_exists():
-		if g.hp < 1 or show_yesno("Leave this game?"):
-			try:
-				window_main.destroy()
-			except TclError:
-				pass
-	elif (g.cur_window == "battle"): #if called from battle window
-		if g.hp < 1 or battle.battle_show_yesno("Leave this game?"):
+	if (g.cur_window == "battle"): #if called from battle window
+		if player.hp < 1 or battle.battle_show_yesno("Leave this game?"):
 			try:
 				window_main.destroy()
 			except TclError:
 				pass
 	elif (g.cur_window == "inventory"): #if called from inventory window
-		if g.hp < 1 or inv.inv_show_yesno("Leave this game?"):
+		if player.hp < 1 or inv.inv_show_yesno("Leave this game?"):
+			try:
+				window_main.destroy()
+			except TclError:
+				pass
+	elif canvas_map.winfo_exists():
+		if player.hp < 1 or show_yesno("Leave this game?"):
 			try:
 				window_main.destroy()
 			except TclError:
@@ -176,7 +178,7 @@ def refresh_tile(x, y):
 def refreshhero():
 	canvas_map.delete("hero")
 	canvas_map.create_image(mapsizex*g.tilesize/2, mapsizey*g.tilesize/2,
-		image=g.tiles[g.cur_hero], tags="hero")
+		image=g.tiles[player.cur_hero], tags="hero")
 
 
 #called to process the onload portion of a level. Called whenever entering
@@ -191,58 +193,58 @@ def process_onload():
 #recalculate and display stats. leave_att_def_alone is for calling from a
 #battle, with the possibility of temp bonuses to attack/defense.
 def recalc_stats(leave_att_def_alone = 0):
-	name.set(g.name)
+	name.set(player.name)
 	if leave_att_def_alone == 0:
 		#adjust attack and defense based on equipment.
-		g.adj_attack = int(g.attack)
-		if g.item.equip[0] != -1:
-			g.adj_attack = g.adj_attack + g.item.item[g.item.equip[0]].quality
+		player.adj_attack = int(player.attack)
+		if player.equip[0] != -1:
+			player.adj_attack = player.adj_attack + g.item.item[player.equip[0]].quality
 		for i in range(6):
-			if g.item.equip[i] != -1:
-				g.adj_attack = g.adj_attack + \
-							g.item.item[g.item.equip[i]].attack_bonus
-		attack.set(g.adj_attack)
+			if player.equip[i] != -1:
+				player.adj_attack = player.adj_attack + \
+							g.item.item[player.equip[i]].attack_bonus
+		attack.set(player.adj_attack)
 
-		g.adj_defense = int(g.defense)
+		player.adj_defense = int(player.defense)
 		for i in range(1, 6):
-			if g.item.equip[i] != -1:
-				g.adj_defense = g.adj_defense + \
-							g.item.item[g.item.equip[i]].quality
+			if player.equip[i] != -1:
+				player.adj_defense = player.adj_defense + \
+							g.item.item[player.equip[i]].quality
 		for i in range(6):
-			if g.item.equip[i] != -1:
-				g.adj_defense = g.adj_defense + \
-							g.item.item[g.item.equip[i]].defense_bonus
-		defense.set(g.adj_defense)
+			if player.equip[i] != -1:
+				player.adj_defense = player.adj_defense + \
+							g.item.item[player.equip[i]].defense_bonus
+		defense.set(player.adj_defense)
 
-	gold.set(g.gold)
-	exp.set(g.exp)
-	level.set(g.level)
+	gold.set(player.gold)
+	exp.set(player.exp)
+	level.set(player.level)
 
-	g.adj_maxhp = int(g.maxhp)
+	player.adj_maxhp = int(player.maxhp)
 	for i in range(6):
-		if g.item.equip[i] != -1:
-			g.adj_maxhp = g.adj_maxhp + g.item.item[g.item.equip[i]].hp_bonus
-	if g.hp > g.adj_maxhp: g.hp = g.adj_maxhp
+		if player.equip[i] != -1:
+			player.adj_maxhp = player.adj_maxhp + g.item.item[player.equip[i]].hp_bonus
+	if player.hp > player.adj_maxhp: player.hp = player.adj_maxhp
 
-	g.adj_maxep = int(g.maxep)
+	player.adj_maxep = int(player.maxep)
 	for i in range(6):
-		if g.item.equip[i] != -1:
-			g.adj_maxep = g.adj_maxep + g.item.item[g.item.equip[i]].ep_bonus
-	if g.ep > g.adj_maxep: g.ep = g.adj_maxep
+		if player.equip[i] != -1:
+			player.adj_maxep = player.adj_maxep + g.item.item[player.equip[i]].ep_bonus
+	if player.ep > player.adj_maxep: player.ep = player.adj_maxep
 
 	#hp/ep bars
 	canvas_hp.delete("show_hp")
-	temp_width = g.hpbar_width*g.hp/g.adj_maxhp
+	temp_width = g.hpbar_width*player.hp/player.adj_maxhp
 	if temp_width < 0: temp_width=0
 	canvas_hp.create_rectangle(0, 0, temp_width,
 		g.hpbar_width/6, fill="#05BB05", tags="show_hp")
 	canvas_ep.delete("show_ep")
-	temp_width = g.hpbar_width*g.ep/g.adj_maxep
+	temp_width = g.hpbar_width*player.ep/player.adj_maxep
 	if temp_width < 0: temp_width=0
 	canvas_ep.create_rectangle(0, 0, temp_width,
 		g.hpbar_width/6, fill="#0505EE", tags="show_ep")
-	hp.set(str(g.hp) + "/" + str(g.adj_maxhp))
-	ep.set(str(g.ep) + "/" + str(g.adj_maxep))
+	hp.set(str(player.hp) + "/" + str(player.adj_maxhp))
+	ep.set(str(player.ep) + "/" + str(player.adj_maxep))
 
 
 #Return an array of pictures that the given tile should display.
@@ -296,10 +298,10 @@ def move_hero(x, y):
 				g.xgrid=g.xgrid + x
 				g.ygrid=g.ygrid + y
 				passturn()
-				if y == -1: g.cur_hero = "people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"
-				if y ==  1: g.cur_hero = "people/hero_s" + g.maps[g.zgrid].hero_suffix + ".png"
-				if x == -1: g.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
-				if x ==  1: g.cur_hero = "people/hero_e" + g.maps[g.zgrid].hero_suffix + ".png"
+				if y == -1: player.cur_hero = "people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"
+				if y ==  1: player.cur_hero = "people/hero_s" + g.maps[g.zgrid].hero_suffix + ".png"
+				if x == -1: player.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
+				if x ==  1: player.cur_hero = "people/hero_e" + g.maps[g.zgrid].hero_suffix + ".png"
 				#Sometimes, quick refresh is bad.
 				global already_refreshed
 				if already_refreshed == 1:
@@ -331,10 +333,10 @@ def move_hero(x, y):
 
 		else:
 			if (tempx == g.xgrid + x) and (tempy == g.ygrid + y):
-				if y == -1: g.cur_hero = "people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"
-				if y ==  1: g.cur_hero = "people/hero_s" + g.maps[g.zgrid].hero_suffix + ".png"
-				if x == -1: g.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
-				if x ==  1: g.cur_hero = "people/hero_e" + g.maps[g.zgrid].hero_suffix + ".png"
+				if y == -1: player.cur_hero = "people/hero_n" + g.maps[g.zgrid].hero_suffix + ".png"
+				if y ==  1: player.cur_hero = "people/hero_s" + g.maps[g.zgrid].hero_suffix + ".png"
+				if x == -1: player.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
+				if x ==  1: player.cur_hero = "people/hero_e" + g.maps[g.zgrid].hero_suffix + ".png"
 			refreshhero()
 			recalc_stats()
 		g.allow_move = 1
@@ -383,7 +385,7 @@ def passturn():
 #Starts a battle. Takes the index of the monster in g.monster.monster_groups
 def start_battle(mon_index):
 	global free_move
-	right.destroy()
+#	right.destroy()
 	button_inv.config(state=DISABLED)
 	button_save.config(state=DISABLED)
 	if battle.begin(mon_index) == 1:  #if you ran, you failed
@@ -392,9 +394,10 @@ def start_battle(mon_index):
 		return_num = 1  #otherwise, you succeeded.
 	#number of free moves after attack:
 	free_move = 4
+	g.cur_window = "main"
 	button_inv.config(state=NORMAL)
 	button_save.config(state=NORMAL)
-	create_map()
+#	create_map()
 	refreshmap()
 	bind_keys()
 	return return_num
@@ -561,7 +564,7 @@ def init_window_main(new_game = 0):
 	#width of the hp/ep bars.
 	g.hpbar_width = g.tilesize*3
 
-	name.set(g.name)
+	name.set(player.name)
 
 	#left (stats) side frame
 	global left
@@ -622,6 +625,7 @@ def init_window_main(new_game = 0):
 	#inventory and movement buttons.
 	global button_inv #global because we need to disable it sometimes.
 	global button_save
+	global button_quit
 	button_inv = Button(left, text="Inventory", underline="0",
 		command=show_inv, bg=buttoncolour)
 	button_inv.grid(row=15, column=1, columnspan=2, sticky=EW)
@@ -629,14 +633,14 @@ def init_window_main(new_game = 0):
 		command=save_game, bg=buttoncolour)
 	button_save.grid(row=16, column=1, columnspan=2, sticky=EW)
 	button_quit = Button(left, text="Quit", underline="0",
-		command=close_window, bg=buttoncolour).grid(row=17, column=1,
-			columnspan=2, sticky=EW)
+		command=close_window, bg=buttoncolour)
+	button_quit.grid(row=17, column=1, columnspan=2, sticky=EW)
 	#this creates the actual map portion.
 	create_map()
 
 	#put in the map, and do finishing touches on the window.
 	process_onload()
-	g.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
+	player.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
 	refreshmap()
 	window_main.wm_geometry("+%d+%d" % (10, 10))
 	window_main.focus()
@@ -645,6 +649,7 @@ def init_window_main(new_game = 0):
 	window_main.title(g.game_name)
 	global free_move
 	free_move = 0
+	g.cur_window = "main"
 
 	bind_keys()
 	window_main.protocol("WM_DELETE_WINDOW", cleanup)
@@ -712,13 +717,13 @@ def show_inv(event=0):
 	try:
 		if window_main.state() != "normal" or action.has_dialog == 1:
 			return
-		right.destroy()
+#		right.destroy()
 		button_inv.config(state=DISABLED)
 		button_save.config(state=DISABLED)
 		inv.init_window_inv()
 		button_inv.config(state=NORMAL)
 		button_save.config(state=NORMAL)
-		create_map()
+#		create_map()
 		refreshmap()
 		recalc_stats()
 		bind_keys()
@@ -726,13 +731,15 @@ def show_inv(event=0):
 		pass
 
 def enter_store(cur_loc):
-	right.destroy()
+#	right.destroy()
 	button_inv.config(state=DISABLED)
 	button_save.config(state=DISABLED)
+	button_quit.config(state=DISABLED)
 	shop.init_window_shop(cur_loc)
 	button_inv.config(state=NORMAL)
 	button_save.config(state=NORMAL)
-	create_map()
+	button_quit.config(state=NORMAL)
+#	create_map()
 	refreshmap()
 	recalc_stats()
 	bind_keys()
