@@ -27,6 +27,8 @@ import Image
 
 import g
 
+from player import *
+
 #if called directly, pick a module.
 if __name__ == "__main__":
 	from os import listdir
@@ -69,7 +71,7 @@ cur_button = 0
 #game-start stuff has been placed in here.
 #It seems to run fast enough, though.
 def reroll_stats():
-	g.name = name.get()
+	player.name = name.get()
 
 	#actual re-rolling
 	hp.set(g.die_roll(g.new_game_dice[0][0], g.new_game_dice[0][1]) +
@@ -88,18 +90,18 @@ def reroll_stats():
 
 #call to reset the game
 def reset_vars():
-	#move variables to g.*
-	g.maxhp = int(hp.get())
-	g.maxep = int(ep.get())
-	g.attack = int(attack.get())
-	g.defense = int(defense.get())
-	g.gold = int(gold.get())
+	#move variables to player.*
+	player.maxhp = int(hp.get())
+	player.maxep = int(ep.get())
+	player.attack = int(attack.get())
+	player.defense = int(defense.get())
+	player.gold = int(gold.get())
 
-	g.exp = 0
-	g.level = 0
-	g.skillpoints = 0
-	g.hp = g.maxhp
-	g.ep = g.maxep
+	player.exp = 0
+	player.level = 0
+	player.skillpoints = 0
+	player.hp = player.maxhp
+	player.ep = player.maxep
 
 	#place the player
 	g.xgrid = 0
@@ -114,23 +116,23 @@ def reset_vars():
 	#clear the inventory
 	for i in range(len(g.item.inv)):
 		g.item.inv[i]= -1
-	for i in range(len(g.item.equip)):
-		g.item.equip[i]= -1
+	for i in range(len(player.equip)):
+		player.equip[i]= -1
 	#clear skills
-	for i in range(len(g.skill)):
-		g.skill[i][5] = 0
+	for i in range(len(player.skill)):
+		player.skill[i][5] = 0
 	global new_game
 	new_game = 1
 
 
 #get stats from g.*
 def get_stats():
-	name.set(g.name)
-	hp.set(g.hp)
-	ep.set(g.ep)
-	attack.set(g.attack)
-	defense.set(g.defense)
-	gold.set(g.gold)
+	name.set(player.name)
+	hp.set(player.hp)
+	ep.set(player.ep)
+	attack.set(player.attack)
+	defense.set(player.defense)
+	gold.set(player.gold)
 
 
 #Use the stats given to create a new character.
@@ -140,13 +142,22 @@ def begin_game():
 
 	#just in case someone changed the name
 	#after rerolling or loading
-	g.name = name.get()
+	player.name = name.get()
 
 	#start the game with 100000 gold if player is named "testing123".
-	if g.name == "testing123":
-		g.gold = 100000
-	if g.name == "":
-		g.name = "Nameless"
+	if player.name == "testing123":
+		player.gold = 100000
+	#god mode
+	if player.name == "god":
+		player.gold = 100000
+		player.maxhp = 100
+		player.hp=100
+		player.maxep = 100
+		player.ep = 100
+		player.attack = 100
+		player.defense = 100
+	if player.name == "":
+		player.name = "Nameless"
 	#bring the main window up.
 	window_new_game.withdraw()
 	main.init_window_main(new_game)
@@ -330,6 +341,7 @@ def init_window():
 	#give basic values.
 	reroll_stats()
 
+
 	#bindings
 	window_new_game.bind(g.binding_cancel, key_handler_esc)
 	window_new_game.bind(g.binding_action, key_handler_return)
