@@ -67,7 +67,7 @@ class map:
 	def del_item(self, itemname, x, y):
 		self.field[y][x].del_item(itemname)
 		g.item.del_dropped_item(itemname, x, y, self.name)
-	def __init__(self, mapname):
+	def __init__(self, mapname, from_editor=0):
 		self.name = mapname
 		self.field = [] #multidimentional array of tile class members.
 		self.monster = [] #monsters that can attack on this level.
@@ -87,7 +87,7 @@ class map:
 
 		#grab the needed data from the file
 		if mapname == "": return
-		map_file = g.read_script_file("/data/maps/" + mapname)
+		map_file = g.read_script_file("/data/maps/" + mapname, from_editor)
 
 		#current mode. 0 for the actual map, 1 for monsters,
 		#2 for tile defines, 3 for per-tile info
@@ -96,18 +96,19 @@ class map:
 		#0 for onload, 1 for action.
 		tilemode=0
 		for map_line in map_file:
+			map_strip = map_line.strip()
 			#go through all lines of the file up to ":def"
 			if curr_mode == 0:
-				if map_line == '' or map_line[:1] == ":":
+				if map_strip == '' or map_strip[:1] == ":":
 					curr_mode = 1
 				else:
 					#add the line
-					line = map_line.split(" ")
+					line = map_strip.split(" ")
 					self.maptext.append(line)
 
 			#input monster data
 			elif curr_mode == 1:
-				if map_line == '' or map_line[:1] == ":":
+				if map_strip == '' or map_strip[:1] == ":":
 					curr_mode = 2
 				else:
 					map_command = map_line.split("=", 2)[0].strip().lower()
@@ -126,59 +127,61 @@ class map:
 
 			#input tile data
 			if curr_mode == 2:
-				if map_line == '':
-					break
+				#if map_line == '':
+				#	break
 				#if per-tile information was given
 				if map_line[:2].lower() == "xy":
 					curr_mode = 3
 					continue
 
 				#is this line giving us a new tile?
-				if map_line[:1] == ":":
-					current_tile = map_line[1:]
+				if map_strip[:1] == ":":
+					current_tile = map_strip[1:]
 					self.tiles[current_tile] = [[], []]
 					tilemode=0
 					continue
 
-				map_command = map_line.strip()
-				if map_command.lower() == "onload":
+				if map_strip.lower() == "onload":
 					tilemode=0
 					continue
-				if map_command.lower() == "action":
+				if map_strip.lower() == "action":
 					tilemode=1
 					continue
 
 				if tilemode == 0: #onload
-					self.tiles[current_tile][0].append(map_command)
+					if from_editor == 1:
+						self.tiles[current_tile][0].append(map_line[:-1])
+					else: self.tiles[current_tile][0].append(map_line)
 				else: #action
-					self.tiles[current_tile][1].append(map_command)
+					if from_editor == 1:
+						self.tiles[current_tile][1].append(map_line[:-1])
+					else: self.tiles[current_tile][1].append(map_line)
 
 			if curr_mode == 3:
-				if map_line == '':
+				if map_strip == '':
 					break
-				if map_line.lower() == "tiles": #switch back
+				if map_strip.lower() == "tiles": #switch back
 					curr_mode = 2
 					continue
 				#is this line giving us a new tile?
-				if map_line[:1] == ":":
-					curr_x = int(map_line[1:].split()[0].strip())
-					curr_y = int(map_line[1:].split()[1].strip())
+				if map_strip[:1] == ":":
+					curr_x = int(map_strip[1:].split()[0].strip())
+					curr_y = int(map_strip[1:].split()[1].strip())
 					self.per_tile_info.append([curr_x, curr_y, [], []])
 					tilemode=0
 					continue
 
-				map_command = map_line.strip()
-				if map_command.lower() == "onload":
+				if map_strip.lower() == "onload":
 					tilemode=0
 					continue
-				if map_command.lower() == "action":
+				if map_strip.lower() == "action":
 					tilemode=1
 					continue
 
 				if tilemode == 0: #onload
-					self.per_tile_info[len(self.per_tile_info)-1][2].append(map_command)
+					self.per_tile_info[len(self.per_tile_info)-1][2].append(map_strip)
 				else: #action
-					self.per_tile_info[len(self.per_tile_info)-1][3].append(map_command)
+					self.per_tile_info[len(self.per_tile_info)-1][3].append(map_strip)
 				continue
 
 		#place the formatted data into self.field
@@ -216,7 +219,7 @@ class map:
 maps = []
 
 #read the data/maps directory and place in maps[]. This called at startup.
-def read_maps():
+def read_maps(from_editor=0):
 	del maps[:]
 	g.load_backgrounds()
 
@@ -241,7 +244,7 @@ def read_maps():
 
 	#go through all maps, adding them to our knowledge.
 	for mapname in array_maps:
-		maps.append(map(mapname))
+		maps.append(map(mapname, from_editor))
 
 
 endgame_act = []
