@@ -27,6 +27,7 @@ import Image
 import main
 import g
 import item
+from player import *
 
 
 
@@ -59,7 +60,7 @@ sell_height=0
 #variables for the middle info display
 item_name  = StringVar()
 item_cost  = StringVar()
-item_value = StringVar()
+#item_value = StringVar()
 item_power = StringVar()
 item_desc  = StringVar()
 curr_gold  = StringVar()
@@ -110,23 +111,25 @@ def refresh_inv():
 			invpos += 1
 
 	#set gold and skillpoints
-	curr_gold.set("Gold: " + str(g.gold))
-	curr_skill.set("Skillpoints: " + str(g.skillpoints))
+	curr_gold.set("Gold: " + str(player.gold))
+	curr_skill.set("Skillpoints: " + str(player.skillpoints))
 	main.recalc_stats()
 
 #Actually sets the info in the middle of the shop screen.
 def set_details(name, cost, value, costtype, power, description, inv_or_shop):
 	item_name.set(name)
 	if inv_or_shop == "shop":
-	   	if cost != "":
+		if cost != "":
 			item_cost.set("Cost: " + str(cost) + " " + costtype)
-			item_value.set("")
-	   	else: item_cost.set("")
+			#item_value.set("")
+			#global label_cost
+			#label_cost.lift()
+		else: item_cost.set("")
 	elif inv_or_shop == "inv":
 	   	if value != "":
-			item_value.set("Value: " + str(value) + " " + costtype)
-			item_cost.set("")
-	   	else: item_value.set("")
+			item_cost.set("Value: " + str(value) + " " + costtype)
+			#item_cost.set("")
+		else: item_cost.set("")
 	if power == "" or power == "-1": item_power.set("")
 	else: item_power.set("Power: " + str(power))
 	canvas_desc.delete("all")
@@ -205,9 +208,9 @@ def sell_item():
 	if (item.item[item.inv[curr_item]].type == 14 and
 		        g.shops[store_num].name == "a Gem Shop"):
 		main.print_message("The Gem Shop owner is happy to pay the true value of your gems.")
-		g.gold = int(g.gold) + item.item[item.inv[curr_item]].price
+		player.gold = int(player.gold) + item.item[item.inv[curr_item]].price
 	else:
-	   	g.gold = int(g.gold) + item.item[item.inv[curr_item]].value
+	   	player.gold = int(player.gold) + item.item[item.inv[curr_item]].value
 
 	main.print_message("You sell your " + item.item[item.inv[curr_item]].name
 		+ ".")
@@ -226,7 +229,7 @@ def buy_item():
 
 	if (g.shops[store_num].itemlist[curr_item].buytype == "gold"):
 		#if enough gold
-		if int(g.shops[store_num].itemlist[curr_item].cost) <= int(g.gold):
+		if int(g.shops[store_num].itemlist[curr_item].cost) <= int(player.gold):
 			#if no actions were given
 			if (len(g.shops[store_num].itemlist[curr_item].actions) == 0):
 				#if given successfully.
@@ -235,7 +238,7 @@ def buy_item():
 						== 1):
 					main.print_message("You buy a " +
 					g.shops[store_num].itemlist[curr_item].item_name + ".")
-					g.gold = int(g.gold) - \
+					player.gold = int(player.gold) - \
 					int(g.shops[store_num].itemlist[curr_item].cost)
 				else: #not enough room
 					main.print_message("Your inventory is full.")
@@ -243,12 +246,12 @@ def buy_item():
 				temp = main.action.activate_lines(0, 0, 0,
 						g.shops[store_num].itemlist[curr_item].actions)
 				if temp == 1:
-					g.gold = int(g.gold) - \
+					player.gold = int(player.gold) - \
 							int(g.shops[store_num].itemlist[curr_item].cost)
 	else: #skillpoints
 		#if enough skillpoints
 		if int(g.shops[store_num].itemlist[curr_item].cost) <= \
-													int(g.skillpoints):
+													int(player.skillpoints):
 			#if no actions were given
 			if (len(g.shops[store_num].itemlist[curr_item].actions) == 0):
 				#if given successfully.
@@ -257,13 +260,13 @@ def buy_item():
 						== 1):
 					main.print_message("You buy a " +
 					g.shops[store_num].itemlist[curr_item].item_name + ".")
-					g.skillpoints = int(g.skillpoints) - \
+					player.skillpoints = int(player.skillpoints) - \
 					int(g.shops[store_num].itemlist[curr_item].cost)
 			else:
 				temp = main.action.activate_lines(0, 0, 0,
 							g.shops[store_num].itemlist[curr_item].actions)
 				if temp == 1:
-					g.skillpoints = int(g.skillpoints) - \
+					player.skillpoints = int(player.skillpoints) - \
 							int(g.shops[store_num].itemlist[curr_item].cost)
 
 	refresh_inv()
@@ -397,7 +400,7 @@ def init_window_shop(store_type_input):
 	global window_shop
 	global bgcolour
 	bgcolour = "lightgrey"
-	window_shop = Frame(main.top, bd=2, relief=SUNKEN, bg=bgcolour)
+	window_shop = Frame(main.top, bd=4, relief=GROOVE, bg=bgcolour)
 	window_shop.grid(row=1, column=5, columnspan=13, sticky=E)
 
 	global curr_item
@@ -448,10 +451,12 @@ def init_window_shop(store_type_input):
 	#Info labels
 	label_name = Label(window_shop, textvar=item_name,
 		wraplength=143, bg=bgcolour).grid(row=8, column=3, sticky=W)
+	global label_cost
 	label_cost = Label(window_shop,
-		textvar=item_cost, bg=bgcolour).grid(row=9, column=3, sticky=W)
-	label_value = Label(window_shop,
-		textvar=item_value, bg=bgcolour).grid(row=9, column=3, sticky=W)
+		textvar=item_cost, bg=bgcolour)
+	label_cost.grid(row=9, column=3, sticky=W)
+# 	label_value = Label(window_shop,
+# 		textvar=item_value, bg=bgcolour).grid(row=9, column=3, sticky=W)
 	label_power = Label(window_shop,
 		textvar=item_power, bg=bgcolour).grid(row=11, column=3, sticky=W)
 
